@@ -79,37 +79,37 @@ def obb(data,edge):
     result = []
     for i in range(data.shape[0]):
         # U1 axis
-        if not separating_axis(Position[i,:],edge[6:9],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],edge[6:9],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # V1 axis
-        if not separating_axis(Position[i,:],edge[9:12],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],edge[9:12],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # W1 axis
-        if not separating_axis(Position[i,:],edge[12:15],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],edge[12:15],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # U2 axis
-        if not separating_axis(Position[i,:],data[i,6:9],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],data[i,6:9],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # V2 axis
-        if not separating_axis(Position[i,:],data[i,9:12],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],data[i,9:12],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # W2 axis
-        if not separating_axis(Position[i,:],data[i,12:15],edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],data[i,12:15],edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
@@ -117,63 +117,63 @@ def obb(data,edge):
         # Mixed Plane Separation Tests
         # U1 X U2
         plane = np.cross(edge[6:9],data[i,6:9])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # U1 X V2
         plane = np.cross(edge[6:9],data[i,9:12])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # U1 X W2
         plane = np.cross(edge[6:9],data[i,12:15])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # V1 X U2
         plane = np.cross(edge[9:12],data[i,6:9])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # V1 X V2
         plane = np.cross(edge[9:12],data[i,9:12])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # V1 X W2
         plane = np.cross(edge[9:12],data[i,12:15])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # W1 X U2
         plane = np.cross(edge[12:15],data[i,6:9])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # W1 X V2
         plane = np.cross(edge[12:15],data[i,9:12])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
             continue
         # W1 X W2
         plane = np.cross(edge[12:15],data[i,12:15])
-        if not separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
+        if separating_axis(Position[i,:],plane,edge[6:9],edge[9:12],edge[12:15],
                            data[i,6:9],data[i,9:12],data[i,12:15],edge[21],edge[21],
                            edge[20]/2,data[i,21],data[i,21],data[i,20]/2):
             result.append(False)
@@ -374,7 +374,8 @@ def collision_free(data,results,idx,terminal,vessel,radius_buffer):
                 return False
     return True
 
-def no_outside_collision(tree,outside_vessels):
+def no_outside_collision(tree,outside_vessels,radius_buffer=0):
+    outside_vessels[:,21] += radius_buffer
     for i in range(outside_vessels.shape[0]):
         n = sphere_proximity(tree.data,outside_vessels[i,:])
         if len(n) == 0:
