@@ -1,4 +1,5 @@
 import os
+from copy import deepcopy
 from .setup import setup as setup_file
 from .paths import paths as path_file
 from .contour import contour as contour_file
@@ -30,9 +31,11 @@ def build(paths,radii,normals,options,setup_file=setup_file,
         path_file = ''
     if options.file_constructor['contour']:
         #contour_file = open(os.path.dirname(__file__)+'/contour.txt','r').readlines()
-        contour_file[8] = contour_file[8].format(options.file_constructor['gui'])
-        for i in range(len(contour_file)):
-            contour_file[i] += "\n"
+        tmp_contour_file = deepcopy(contour_file)
+        tmp_contour_file[8] = tmp_contour_file[8].format(options.file_constructor['gui'])
+        #print(contour_file[8])
+        for i in range(len(tmp_contour_file)):
+            tmp_contour_file[i] += "\n"
     else:
         contour_file = ''
     if options.file_constructor['solid']:
@@ -190,19 +193,19 @@ def build(paths,radii,normals,options,setup_file=setup_file,
     ############################################################
     # BUILDING SV CONTOURS
     ############################################################
-    cco_file_text += contour_file[0]
-    cco_file_text += contour_file[1]
+    cco_file_text += tmp_contour_file[0]
+    cco_file_text += tmp_contour_file[1]
     for idx, path in enumerate(paths):
-        cco_file_text += contour_file[2].format(idx)
-        cco_file_text += contour_file[3].format(idx)
+        cco_file_text += tmp_contour_file[2].format(idx)
+        cco_file_text += tmp_contour_file[3].format(idx)
         contours = zip(paths[idx],radii[idx],normals[idx])
         for jdx,contour in enumerate(contours):
-            cco_file_text += contour_file[4].format(idx,contour[1],contour[0],contour[2])
-            cco_file_text += contour_file[5].format(idx,idx)
-        cco_file_text += contour_file[6].format(idx)
-        cco_file_text += contour_file[7].format(idx)
-        cco_file_text += contour_file[8]
-        cco_file_text += contour_file[9].format(idx,idx,idx)
+            cco_file_text += tmp_contour_file[4].format(idx,contour[1],contour[0],contour[2])
+            cco_file_text += tmp_contour_file[5].format(idx,idx)
+        cco_file_text += tmp_contour_file[6].format(idx)
+        cco_file_text += tmp_contour_file[7].format(idx)
+        cco_file_text += tmp_contour_file[8]
+        cco_file_text += tmp_contour_file[9].format(idx,idx,idx)
     ############################################################
     ############################################################
 
